@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Gufw 13.10.0 - http://gufw.org
+# Gufw 13.10.2 - http://gufw.org
 # Copyright (C) 2008-2013 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -21,9 +21,9 @@ import os
 
 
 class WinAbout:
-    """All events"""
     def __init__(self, winMain):
         self.builder = Gtk.Builder()
+        self.builder.set_translation_domain("gufw")
         self.builder.add_from_file(os.path.join('/usr', 'share', 'gufw', 'ui', 'about.ui'))
         self.win_about = self.builder.get_object('about')
         self.win_about.set_transient_for(winMain)
