@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Gufw 13.10.0 - http://gufw.org
+# Gufw 13.10.2 - http://gufw.org
 # Copyright (C) 2008-2013 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -36,6 +36,7 @@ class WinAdd:
         self.apps = AppProfiles()
         
         self.builder = Gtk.Builder()
+        self.builder.set_translation_domain("gufw")
         self.builder.add_from_file('/usr/share/gufw/ui/add.ui')
         self._set_objects_name()
         self._set_initial_values()
@@ -112,7 +113,7 @@ class WinAdd:
             self.preconfig_app.append_text(app)
         self.preconfig_app.set_active(0)
         
-        tooltip = self.apps.get_app(self.preconfig_app.get_active_text())[0] + '\n' + _("Ports: ") + self.apps.get_app(self.preconfig_app.get_active_text())[1]
+        tooltip = self.apps.get_app(self.preconfig_app.get_active_text())[0] + '\n' + _("Ports") + ": " + self.apps.get_app(self.preconfig_app.get_active_text())[1]
         self.img_description.set_tooltip_text(tooltip)
     
     def on_btnAddClose_clicked(self, widget, data=None):
@@ -201,7 +202,7 @@ class WinAdd:
             self.advanced_iface.set_sensitive(False)
     
     def on_preconfig_category_changed(self, widget, data=None):
-        # Delete all entries
+        # Delete all subcategories
         self.preconfig_subcategory.remove_all()
         # Append new entries
         subcategories = self.apps.get_subcategories(self.preconfig_category.get_active_text())
@@ -210,7 +211,7 @@ class WinAdd:
         self.preconfig_subcategory.set_active(0)
     
     def on_preconfig_subcategory_changed(self, widget, data=None):
-        # Delete all entries
+        # Delete all apps
         self.preconfig_app.remove_all()
         # Append new entries
         apps = self.apps.get_apps_cat_subcat(self.preconfig_category.get_active_text(), self.preconfig_subcategory.get_active_text())
@@ -220,7 +221,7 @@ class WinAdd:
     
     def on_preconfig_app_changed(self, widget, data=None):
         if self.preconfig_app.get_active_text() != None:
-            tooltip = self.apps.get_app(self.preconfig_app.get_active_text())[0] + '\n' + _("Ports: ") + self.apps.get_app(self.preconfig_app.get_active_text())[1]
+            tooltip = self.apps.get_app(self.preconfig_app.get_active_text())[0] + '\n' + _("Ports") + ": " + self.apps.get_app(self.preconfig_app.get_active_text())[1]
             self.img_description.set_tooltip_text(tooltip)
             if self.apps.get_app(self.preconfig_app.get_active_text())[3]:
                 self.lbl_inforule.set_text(self.apps.get_app(self.preconfig_app.get_active_text())[3])
@@ -230,7 +231,7 @@ class WinAdd:
     
     def on_btnAddRuleWin_clicked(self, widget, data=None):
         if not self.fw.get_status():
-            self.utils.show_dialog(_("Error: Firewall is disabled"), _("The firewall has to be enabled before"))
+            self.utils.show_dialog(_("Error: Firewall is disabled"), _("The firewall has to be enabled first"))
             return
         
         if self.tabs.get_current_page() == 0:
@@ -255,18 +256,22 @@ class WinAdd:
                 
                 from_port = from_split
                 to_port = to_split
-                cmd = self.fw.add_rule(name, insert, policy, direction, iface, logging, proto, from_ip, from_port, to_ip, to_port)
+                if direction == 'both':
+                    cmd = self.fw.add_rule(name, insert, policy, 'in',  iface, logging, proto, from_ip, from_port, to_ip, to_port)
+                    cmd = self.fw.add_rule(name, insert, policy, 'out', iface, logging, proto, from_ip, from_port, to_ip, to_port)
+                else:
+                    cmd = self.fw.add_rule(name, insert, policy, direction, iface, logging, proto, from_ip, from_port, to_ip, to_port)
                 
                 if cmd[0]:
                     flag_Warning = True
                     self.utils.add_to_log(cmd[1])
                 else:
                     flag_OK = False
-                    self.utils.add_to_log(_("Error running: ") + cmd[1] + ' > ' + cmd[2].replace('\n', ' | '))
+                    self.utils.add_to_log(_("Error running") + ": " + cmd[1] + ' > ' + cmd[2].replace('\n', ' | '))
         
         # OK
         if flag_OK and flag_Warning:
-            self.utils.set_statusbar_msg(_("Rule/s added"))
+            self.utils.set_statusbar_msg(_("Rule(s) added"))
         # Some OK, some KO
         elif flag_OK and not flag_Warning:
             self.utils.set_statusbar_msg(_("Warning: Some rules added. Review the log"))
@@ -291,6 +296,10 @@ class WinAdd:
             self.utils.show_dialog(_("Insert Port"), _("You need to insert a port in the port field"))
             return
         
+        if self.simple_port.get_text().upper() == 'PRISM':
+            self.utils.show_dialog(_("Edward Snowden's Greatest Fear"), _('"Nothing Will Change"'))
+            return
+        
         self._add(self.fw.get_profile(),                            # profile
                  self.simple_rule_name.get_text(),                  # name
                  NUM2POLICY[self.simple_policy.get_active()],       # policy
@@ -369,8 +378,10 @@ class AppProfiles:
                 warning = cfg.get(section, "warning")
                 
             if title and description and ports and categories:
-                apps[title] = [_(description), _(ports), _(categories), _(warning)]
-        
+                if warning != '':
+                    apps[_(title)] = [_(description), ports, _(categories), _(warning)]
+                else:
+                    apps[_(title)] = [_(description), ports, _(categories), '']
         return apps
     
     def _get_all_categories(self):
@@ -395,7 +406,10 @@ class AppProfiles:
         for cat in self.all_categories:
             current_cat = cat.split(';')[0]
             if category == current_cat:
-                current_subcat = cat.split(';')[1]
+                try:
+                    current_subcat = cat.split(';')[1]
+                except:
+                    current_subcat = ''
                 if not subcateg.count(current_subcat) and current_subcat:
                     subcateg.append(current_subcat)
         subcateg.sort()
@@ -405,8 +419,11 @@ class AppProfiles:
     def get_apps_cat_subcat(self, cat, subcat):
         apps = []
         for app in self.all_apps:
-            current_cat    = self.all_apps[app][2].split(';')[0]
-            current_subcat = self.all_apps[app][2].split(';')[1]
+            current_cat = self.all_apps[app][2].split(';')[0]
+            try:
+                current_subcat = self.all_apps[app][2].split(';')[1]
+            except:
+                current_subcat = ''
             if ( ( cat == current_cat and subcat == _("All") ) or
                  ( cat == current_cat and subcat == current_subcat ) ):
                 apps.append(app)
