@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Gufw 13.10.0 - http://gufw.org
+# Gufw 13.10.2 - http://gufw.org
 # Copyright (C) 2008-2013 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 from gi.repository import Gtk, Gdk, GObject, WebKit
 from string import Template
 
-import os, re, sys, subprocess
+import os, re, sys, subprocess, platform
 
 import gettext
 from gettext import gettext as _
@@ -40,6 +40,7 @@ class Gufw:
         self.fw = frontend
         
         self.builder = Gtk.Builder()
+        self.builder.set_translation_domain("gufw")
         self.builder.add_from_file('/usr/share/gufw/ui/main.ui')
         
         self._set_objects_name()
@@ -77,6 +78,10 @@ class Gufw:
         self.log_copy     = self.builder.get_object('btnLogCopy')
         self.log_delete   = self.builder.get_object('btnLogCopy')
         
+        self.web = self.builder.get_object('boxWeb')
+        self.web_context = WebKit.WebView()
+        self.web.add(self.web_context)
+        
         self.statusbar    = self.builder.get_object('statusmsg')
         self.progress     = self.builder.get_object('progress')
         
@@ -147,25 +152,26 @@ class Gufw:
         tree_header = Gtk.TreeViewColumn (_("Application"), self.render_txt, text=3, foreground=4)
         self.tv_report.append_column (tree_header)
         
-        self._load_tutorial()
-        
         if self.fw.get_config_value('ExpandRules') == 'yes':
-            self.tuto.hide()
+            self.web.hide()
             self.rules_expander.set_expanded(True)
             self.rules_box.show()
         
         if self.fw.get_config_value('ExpandListening') == 'yes':
-            self.tuto.hide()
+            self.web.hide()
             self.report_expander.set_expanded(True)
             self.report_box.show()
             self.listening.starting()
         
         if self.fw.get_config_value('ExpandLog') == 'yes':
-            self.tuto.hide()
+            self.web.hide()
             self.log_expander.set_expanded(True)
             self.log_box.show()
             self.utils.add_to_log(self.fw.get_log(), GRAY, False)
         
+        self.web_context.show()
+        self._show_tutorial(self.rules_expander.get_expanded(), self.report_expander.get_expanded(), self.log_expander.get_expanded())
+        
         self._set_shield()
         
         self.utils.restore_window_size(self.winMain)
@@ -177,48 +183,25 @@ class Gufw:
         if self.fw.get_config_value('ShowDonationBtn') == 'no':
             self.donateBox.hide()
     
-    def _launch_browser(self, url):
-        try:
-            user = sys.argv[1]
-        except:
-            self.utils.show_dialog(_("Visit this web (copy & paste):"), url)
-            return
-        
-        if not user or user == 'root':
-            self.utils.show_dialog(_("Visit this web (copy & paste):"), url)
-            return
-            
-        cmd = "su -l " + user + " -c 'python -mwebbrowser " + url + "'"
-        
-        subprocess.Popen(cmd, shell=True)
-    
     def _load_tutorial(self):
-        self.tuto = self.builder.get_object('boxTutorial')
-        self.tuto_web = WebKit.WebView()
-        self.tuto.add(self.tuto_web)
-        
-        self.tuto.show()
-        self.tuto_web.show()
-        #self.tuto_web.set_transparent(True)
-        
         f = open(TUTORIAL_FILE, 'r')
         html_content = f.read()  
         f.close()
         
         replace_html = dict(heading1=_("Getting started"),
                             welcome=_("What is Gufw?"),
-                            intro=_("An uncomplicated way to manage your firewall. Easy, simple and beautiful :)"),
+                            intro=_("An uncomplicated way to manage your firewall. Easy, simple, nice and useful! :)"),
                             heading2=_("Basic"),
                             heading3=_("FAQ"),
-                            best_conf=_("If you are a normal user, you will be safe with this setting (Status=On, Incoming=Deny, Outgoing=Allow). Remember append allow rules for your P2P apps:"),
+                            best_conf=_("If you are a normal user, you will be safe with this setting (Status=On, Incoming=Deny, Outgoing=Allow). Remember to append allow rules for your P2P apps:"),
                             rename_profile=_("You can rename your profiles with just 2 clicks on them:"),
                             rule_name=_("The Rule Name will help you to identify your rules in the future:"),
                             faq1_q=_("How to autostart Gufw with the system?"),
-                            faq1_a=_("You don't need it. After you do all of the changes in Gufw and close it, the settings are still in effect."),
-                            faq2_q=_("Why is disabled by default?"),
+                            faq1_a=_("You do not need it. After you do all of the changes in Gufw, the settings are still in place until the next changes."),
+                            faq2_q=_("Why is Gufw disabled by default?"),
                             faq2_a=_("By default, the firewall does not open ports to the outside world."),
-                            faq3_q=_("Some rules are added by himself?"),
-                            faq3_a=_("Well, when you change or import a profile, or when you edit a rule, Gufw is re-adding that rule. ufw is adding for IPv4 and IPv6, then this is the behavior. Sorry about that."),
+                            faq3_q=_("Some rules are added by themselves?"),
+                            faq3_a=_("Well, the behaviour is such that when you change or import a profile, or when you edit a rule, Gufw readds that rule, then ufw readds for IPv4 and IPv6."),
                             faq4_q=_("What is Allow, Deny, Reject and Limit?"),
                             faq4_a1=_("Allow: Will allow traffic."),
                             faq4_a2=_("Deny: Will deny traffic."),
@@ -226,10 +209,15 @@ class Gufw:
                             faq4_a4=_("Limit: Will deny traffic if an IP tried several connections."),
                             faq5_q=_("I see some rules in all profiles"),
                             faq5_a=_("All the ufw rules will be appear in all profiles."),
-                            faq6_q=_("I want even more! :)"),
-                            faq6_a=_("Visit the community documentation"))
+                            faq6_q=_("Can I use Gufw in a remote computer or without graphical environment, as Ubuntu Server?"),
+                            faq6_a1=_("Yes! Export your X display ;) You will need a client \"A\" with graphic environment and a server \"B\" with Gufw. Then, run from client \"A\":"),
+                            faq6_a2 = "ssh user@IP -X",
+                            faq6_a3 = "sudo /usr/bin/gufw-pkexec -ssh",
+                            faq6_a4=_("Gufw will appear in your client \"A\" and all the operations will be apply in the server \"B\". Please, read the community documentation for a complete information."),
+                            faq7_q=_("I want even more! :)"),
+                            faq7_a=_("Visit the community documentation"))
         html = Template(html_content).safe_substitute(replace_html)
-        self.tuto_web.load_html_string(html, "file:///")
+        self.web_context.load_html_string(html, "file:///")
     
     def on_expanderRules_activate(self, widget, data=None):
         if not self.rules_expander.get_expanded():
@@ -255,9 +243,27 @@ class Gufw:
     
     def _show_tutorial(self, rules, report, log):
         if not rules and not report and not log:
-            self.tuto.show()
+            self.web.show()
+            self._load_tutorial()
         else:
-            self.tuto.hide()
+            self.web.hide()
+    
+    def _show_web(self, url):
+        distro = platform.linux_distribution()[0].lower()
+        try:
+            user = sys.argv[1]
+        except:
+            self.utils.show_dialog(_("Visit this web (please, copy & paste in your browser):"), url)
+            return
+        
+        if ( (distro != 'ubuntu' and distro != 'linuxmint')
+           or not user or user == 'root' or user == '-ssh' ):
+            self.utils.show_dialog(_("Visit this web (please, copy & paste in your browser):"), url)
+            return
+        
+        # This works in some distros. In others, open an (hidden) Terminal with the URL in text mode
+        cmd = "gksu -u " + user + " 'python -m webbrowser -t \"" + url + "\"'"
+        subprocess.Popen(cmd, shell=True)
     
     def on_expanderLog_activate(self, widget, data=None):
         if not self.log_expander.get_expanded():
@@ -276,27 +282,27 @@ class Gufw:
         profile = os.path.splitext(profile)[0] # Ext
         
         if not profile:
-            self.utils.set_statusbar_msg(_("Import canceled"))
+            self.utils.set_statusbar_msg(_("Import cancelled"))
             return
         
         if not re.match('^[A-Za-z0-9_-]*$', profile):
-            self.utils.show_dialog(_("Error"), _("Filename has not valid characters. Rename the file to only letters and numbers"))
+            self.utils.show_dialog(_("Error"), _("Filename has not valid characters. Rename the file to only letters, numbers, dashes and underscores"))
             return
         
         if profile in self.fw.get_all_profiles():
-            self.utils.set_statusbar_msg(_("Operation canceled"))
+            self.utils.set_statusbar_msg(_("Operation cancelled"))
             self.utils.show_dialog(_("Error"), _("Profile already exists"))
         else:
             self.fw.import_profile(import_profile)       
             self.profile.append_text(profile)
             self.utils.add_to_log(_("Profile imported") + ": " + import_profile)
-            self.utils.set_statusbar_msg(_("Profile imported, now you can choose in the profiles"))
+            self.utils.set_statusbar_msg(_("Profile imported, now you can choose it in the profiles"))
     
     def on_menu_export_activate(self, widget, data=None):
         export_profile = self.utils.file_dialog('save', _("Export Profile"))
         
         if not export_profile:
-            self.utils.set_statusbar_msg(_("Export canceled"))
+            self.utils.set_statusbar_msg(_("Export cancelled"))
             return
         
         if export_profile[-8:] != '.profile':
@@ -345,7 +351,7 @@ class Gufw:
         self.utils.set_statusbar_msg(_("Text copied to clipboard"))
     
     def on_donate_btn_clicked(self, widget, data=None):
-        self._launch_browser(URL_DONATE)
+        self._show_web(URL_DONATE)
     
     def on_donate_hide_btn_clicked(self, widget, data=None):
         self.fw.set_config_value('ShowDonationBtn', 'no')
@@ -355,31 +361,31 @@ class Gufw:
         about = WinAbout(self.winMain)
     
     def on_menu_doc_activate(self, widget, data=None):
-        self._launch_browser(URL_DOC)
+        self._show_web(URL_DOC)
     
     def on_menu_answers_activate(self, widget, data=None):
-        self._launch_browser(URL_ANSWERS)
+        self._show_web(URL_ANSWERS)
     
     def on_menu_bugs_activate(self, widget, data=None):
-        self._launch_browser(URL_BUGS)
+        self._show_web(URL_BUGS)
     
     def on_menu_translations_activate(self, widget, data=None):
-        self._launch_browser(URL_TRANSLATIONS)
+        self._show_web(URL_TRANSLATIONS)
     
     def on_menu_donate_activate(self, widget, data=None):
-        self._launch_browser(URL_DONATE)
+        self._show_web(URL_DONATE)
     
     def on_menu_gplus_activate(self, widget, data=None):
-        self._launch_browser(URL_GPLUS)
+        self._show_web(URL_GPLUS)
     
     def on_menu_gplus_community_activate(self, widget, data=None):
-        self._launch_browser(URL_GPLUSCOMUNITY)
+        self._show_web(URL_GPLUSCOMUNITY)
     
     def on_menu_twitter_activate(self, widget, data=None):
-        self._launch_browser(URL_TWITTER)
+        self._show_web(URL_TWITTER)
     
     def on_menu_identica_activate(self, widget, data=None):
-        self._launch_browser(URL_IDENTICA)
+        self._show_web(URL_IDENTICA)
     
     def on_menu_preferences_activate(self, widget, data=None):
         preferences = WinPreferences(self.fw, self.utils, self.profile, self.winMain)
@@ -387,18 +393,18 @@ class Gufw:
     def on_incoming_changed(self, widget, data=None):
         self.fw.set_policy('incoming', NUM2POLICY[self.incoming.get_active()].lower())
         self._set_shield()
-        self.utils.add_to_log(_("Incoming: ") + self.incoming.get_active_text(), POLICY2COLOR[self.fw.get_policy('incoming')])
+        self.utils.add_to_log(_("Incoming") + ": " + self.incoming.get_active_text(), POLICY2COLOR[self.fw.get_policy('incoming')])
         self.utils.set_statusbar_msg(_("Incoming policy changed"))
         if self.fw.get_policy('incoming') != NUM2POLICY[self.incoming.get_active()].lower():
-            self.utils.show_dialog(_("There was an error changing the incoming policy"), _("Restart your firewall for refresh the real status and please report this bug"))
+            self.utils.show_dialog(_("There was an error changing the incoming policy"), _("Restart your firewall to refresh to the real status and please report this bug"))
     
     def on_outgoing_changed(self, widget, data=None):
         self.fw.set_policy('outgoing', NUM2POLICY[self.outgoing.get_active()].lower())
         self._set_shield()
-        self.utils.add_to_log(_("Outgoing: ") + self.outgoing.get_active_text(), POLICY2COLOR[self.fw.get_policy('outgoing')])
+        self.utils.add_to_log(_("Outgoing") + ": " + self.outgoing.get_active_text(), POLICY2COLOR[self.fw.get_policy('outgoing')])
         self.utils.set_statusbar_msg(_("Outgoing policy changed"))
         if self.fw.get_policy('outgoing') != NUM2POLICY[self.outgoing.get_active()].lower():
-            self.utils.show_dialog(_("There was an error changing the outgoing policy"), _("Restart your firewall for refresh the real status and please report this bug"))
+            self.utils.show_dialog(_("There was an error changing the outgoing policy"), _("Restart your firewall to refresh to the real status and please report this bug"))
     
     def on_btnAddRule_clicked(self, widget, data=None):
         self.show_add_win.set_sensitive(False)
@@ -420,7 +426,7 @@ class Gufw:
         self.detele_rule_btn.set_sensitive(self.fw.get_status())
         self._set_shield()
         if self.fw.get_status() != self.switchStatus.get_active():
-            self.utils.show_dialog(_("There was an error changing the status firewall"), _("Restart your firewall for refresh the real status and please report this bug"))
+            self.utils.show_dialog(_("There was an error changing the firewall status"), _("Restart your firewall to refresh to the real status and please report this bug"))
 
     def on_btnDeleteRule_clicked(self, widget, data=None):
         rules_selected = False
@@ -437,9 +443,9 @@ class Gufw:
             
             if len(rules_before) != len(rules_after):
                 self.utils.add_to_log(cmd[0])
-                self.utils.set_statusbar_msg(_("Rule/s deleted"))
+                self.utils.set_statusbar_msg(_("Rule(s) deleted"))
             else:
-                self.utils.add_to_log(_("Error running: ") + cmd[0] + ' > ' + cmd[1].replace('\n', ' | '))
+                self.utils.add_to_log(_("Error running") + ": " + cmd[0] + ' > ' + cmd[1].replace('\n', ' | '))
                 self.utils.set_statusbar_msg(_("Error. Review Gufw Log"))
         
         if rules_selected:
@@ -491,6 +497,7 @@ class Gufw:
 
     def on_profile_changed(self, widget, data=None):
         operation = self.fw.set_profile(self.profile.get_active_text())
+        self.utils.add_to_log(_("Changing to a new profile") + ": " + self.profile.get_active_text())
         
         self.incoming.set_active(POLICY2NUM[self.fw.get_policy('incoming')])
         self.outgoing.set_active(POLICY2NUM[self.fw.get_policy('outgoing')])
