@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Gufw 13.10.0 - http://gufw.org
+# Gufw 13.10.2 - http://gufw.org
 # Copyright (C) 2008-2013 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -33,6 +33,7 @@ class WinPreferences:
         self.utils = utils
         
         self.builder = Gtk.Builder()
+        self.builder.set_translation_domain("gufw")
         self.builder.add_from_file('/usr/share/gufw/ui/preferences.ui')
         self._set_objects_name(profile_cb)
         self._set_initial_values()
@@ -79,9 +80,13 @@ class WinPreferences:
         if not new_name:
             self.utils.show_dialog(_("Profile not valid"), _("Enter at least one character"))
             return
+        # Length
+        if len(new_name) > 15:
+            self.utils.show_dialog(_("Profile not valid"), _("Too long! (max. 15 characters)"))
+            return
         # Check only ASCII characters and no spaces
         if not re.match('^[A-Za-z0-9_-]*$', new_name):
-            self.utils.show_dialog(_("Profile not valid"), _("Use only letters and numbers"))
+            self.utils.show_dialog(_("Profile not valid"), _("Use only letters, numbers, dashes and underscores"))
             return
         # Exist?
         for searched_profile in self.profile_rows:
@@ -98,7 +103,7 @@ class WinPreferences:
         self.profile_rows[path][0] = new_name
         self.main_profile_cb.remove(int(path))
         self.main_profile_cb.insert_text(int(path), new_name)
-        self.utils.add_to_log(_("Edited Profile: ") + new_name)
+        self.utils.add_to_log(_("Edited Profile") + ": " + new_name)
     
     def on_AddProfile_btn_clicked(self, widget, data=None):
         """Add a profile"""
@@ -117,7 +122,7 @@ class WinPreferences:
         ind = self.fw.get_all_profiles().index(new_name)
         self.profile_rows.append([new_name])
         self.main_profile_cb.append_text(new_name)
-        self.utils.add_to_log(_("New Profile: ") + new_name)
+        self.utils.add_to_log(_("New Profile") + ": " + new_name)
         
     def on_DeleteProfile_btn_clicked(self, widget, data=None):
         model, treeiter = self.list_selection.get_selected()
@@ -131,11 +136,11 @@ class WinPreferences:
                 self.main_profile_cb.remove(self.fw.get_all_profiles().index(deleted_profile))
                 self.fw.delete_profile(deleted_profile)
                 self.profile_rows.remove(treeiter)
-                self.utils.add_to_log(_("Deleted Profile: ") + deleted_profile)
+                self.utils.add_to_log(_("Deleted Profile") + ": " + deleted_profile)
  
     def on_ufw_logging_changed(self, widget, data=None):
         self.fw.set_ufw_logging(NUM2UFW_LEVEL[self.ufw_logging.get_active()])
-        self.utils.add_to_log(_("ufw Logging: ") + self.ufw_logging.get_active_text())
+        self.utils.add_to_log(_("ufw Logging") + ": " + self.ufw_logging.get_active_text())
     
     def on_gufw_logging_toggled(self, widget, data=None):
         if self.gufw_logging.get_active():
