@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Gufw 13.10.0 - http://gufw.org
+# Gufw 13.10.2 - http://gufw.org
 # Copyright (C) 2008-2013 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -49,6 +49,7 @@ class UpdateRule:
         self.rule_logging     = logging
 
         self.builder = Gtk.Builder()
+        self.builder.set_translation_domain("gufw")
         self.builder.add_from_file('/usr/share/gufw/ui/update.ui')
         self._set_objects_name()
         self._set_initial_values()
@@ -192,20 +193,20 @@ class UpdateRule:
             self.rule_to_port     == new_to_port     and
             self.rule_iface       == new_iface       and
             self.rule_logging     == new_logging):
-            self.utils.set_statusbar_msg(_("There were not changes"))
+            self.utils.set_statusbar_msg(_("No changes were made"))
             return
         
         # Delete the same rules
         same_rules_rows = self._get_same_rules(self.rule_cmd)
         for same_row in reversed(same_rules_rows):
             cmd = self.fw.delete_rule(same_row)
-            self.utils.add_to_log(_("Deleted rule: ") + new_description + ' | ' + cmd[0] + ' > ' + cmd[1].replace('\n', ' | '))
+            self.utils.add_to_log(_("Deleted rule") + ": " + new_description + ' | ' + cmd[0] + ' > ' + cmd[1].replace('\n', ' | '))
         
         # Add new
         insert_row = ''
         cmd = self.fw.add_rule(new_description, insert_row, new_policy, new_direction, new_iface, new_logging, new_proto, new_from_ip, new_from_port, new_to_ip, new_to_port)
 
-        self.utils.add_to_log(_("Added rule: ") + new_description + ' | ' + cmd[1] + ' > ' + cmd[2].replace('\n', ' | '), POLICY2COLOR[new_policy])
+        self.utils.add_to_log(_("Added rule") + ": " + new_description + ' | ' + cmd[1] + ' > ' + cmd[2].replace('\n', ' | '), POLICY2COLOR[new_policy])
         self.utils.set_statusbar_msg(_("Updated rule ") + str(self.ufw_row))
         
         self.utils.print_rules(self.fw.get_rules())
